package cz.muni.fi.pa165.core;

import cz.muni.fi.pa165.core.device.Device;
import cz.muni.fi.pa165.core.device.DeviceService;
import cz.muni.fi.pa165.core.smartmeter.SmartMeter;
import cz.muni.fi.pa165.core.smartmeter.SmartMeterService;
import cz.muni.fi.pa165.core.user.User;
import cz.muni.fi.pa165.core.user.UserService;
import cz.muni.fi.pa165.core.user.UserType;
import lombok.RequiredArgsConstructor;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.stereotype.Component;

@RequiredArgsConstructor
@Component
public class DataInitializer implements ApplicationRunner {
	private final UserService userService;
	private final DeviceService deviceService;
	private final SmartMeterService smartMeterService;

	@Override
	public void run(ApplicationArguments args) throws Exception {
		SeedUsers();
		SeedDevice();
		SeedSmartMeter();
	}

	private void SeedUsers(){
		User user = User.builder()
				.email("test@email.com")
				.firstName("John")
				.lastName("Doe")
				.username("johnD")
				.password("password")
				.userType(UserType.ADMIN)
				.build();
		userService.create(user);
	}

	private void SeedDevice(){
		Device device = Device.builder()
				.name("device01")
				.build();
		deviceService.create(device);
	}

	private void SeedSmartMeter(){
		Device device = Device.builder()
				.name("device02")
				.build();
		deviceService.create(device);

		SmartMeter smartMeter = SmartMeter.builder()
				.device(device)
				.build();
		smartMeterService.create(smartMeter);
	}
}
