package cz.muni.fi.pa165.core.common;

import jakarta.persistence.EntityNotFoundException;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

public abstract class DomainService<T extends DomainObject> {

	public static final int DEFAULT_PAGE_SIZE = 10;

	public abstract JpaRepository<T, String> getRepository();

	@Transactional
	public T create(T entity) {
		return getRepository().save(entity);
	}

	@Transactional(readOnly = true)
	public Page<T> findAllPageable(Pageable pageable) {
		return getRepository().findAll(pageable);
	}

	@Transactional(readOnly = true)
	public List<T> findAll() {
		return getRepository().findAll();
	}

	@Transactional(readOnly = true)
	public Page<T> findAllPageableInt(int page) {
		return getRepository().findAll(PageRequest.of(page, DEFAULT_PAGE_SIZE));
	}

	@Transactional(readOnly = true)
	public T findById(String id){
		return getRepository().findById(id).orElseThrow(() -> new EntityNotFoundException("Entity with '"+ id + "' not found."));
	}
}

