package cz.muni.fi.pa165.core.device;

import cz.muni.fi.pa165.model.dto.device.DeviceCreateDto;
import cz.muni.fi.pa165.model.dto.device.DeviceDto;
import cz.muni.fi.pa165.model.dto.device.DeviceUpdateDto;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/device")
public class DeviceController {

  private final DeviceService deviceService;

  private final DeviceMapper mapper;

  @Autowired
  public DeviceController(DeviceService deviceService, DeviceMapper mapper) {
    this.deviceService = deviceService;
    this.mapper = mapper;
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Get all devices pageable",
      description = "...")
  @GetMapping("pageable")
  public List<DeviceDto> findAllPageable(Pageable pageable) {
    return mapper.toDtoList((List<Device>) deviceService.findAllPageable(pageable));
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Get all devices",
      description = "...")
  @CrossOrigin(origins = "*")
  @GetMapping // CORS headers needed for JavaScript clients
  public List<DeviceDto> findAll() {
    return mapper.toDtoList(deviceService.findAll());
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Get device by id",
      description = "...")
  @GetMapping("/{id}")
  public DeviceDto find(@PathVariable String id) {
    return mapper.toDto(deviceService.findById(id));
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Create device",
      description = "...")
  @PostMapping
  public DeviceDto create(@RequestBody DeviceCreateDto deviceDto) {
    return mapper.toDto(deviceService.create(mapper.fromCreateDto(deviceDto)));
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Update device",
      description = "...")
  @PutMapping
  public DeviceDto update(@RequestBody DeviceUpdateDto deviceDto) {
    return mapper.toDto(deviceService.create(mapper.fromUpdateDto(deviceDto)));
  }
}
