package cz.muni.fi.pa165.core.smartmeter;

import cz.muni.fi.pa165.model.dto.smartDevice.SmartMeterCreateDto;
import cz.muni.fi.pa165.model.dto.smartDevice.SmartMeterDto;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/smart-meter")
public class SmartMeterController {
  private final SmartMeterService smartMeterService;
  private final SmartMeterMapper mapper;

  @Autowired
  public SmartMeterController(SmartMeterService smartMeterService, SmartMeterMapper mapper) {
    this.smartMeterService = smartMeterService;
    this.mapper = mapper;
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Get all smartMeter pageable",
      description = "...")
  @GetMapping("pageable")
  public List<SmartMeterDto> findAllPageable(Pageable pageable) {
    return mapper.toDtoList((List<SmartMeter>) smartMeterService.findAllPageable(pageable));
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Get all smartMeters",
      description = "...")
  @CrossOrigin(origins = "*")
  @GetMapping // CORS headers needed for JavaScript clients
  public List<SmartMeterDto> findAll() {
    return mapper.toDtoList(smartMeterService.findAll());
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Get smartMeter by id",
      description = "...")
  @GetMapping("/{id}")
  public SmartMeterDto find(@PathVariable String id) {
    return mapper.toDto(smartMeterService.findById(id));
  }

  @Operation( // metadata for inclusion into OpenAPI document
      summary = "Create smartMeter",
      description = "...")
  @PostMapping
  public SmartMeterDto create(@RequestBody SmartMeterCreateDto smartMeterDto) {
    return mapper.toDto(smartMeterService.create(mapper.fromCreateDto(smartMeterDto)));
  }
}
